@@ -262,6 +262,7 @@ declare_value_struct_conversion!(struct sixtyfps_corelib::input::KeyboardModifie
 declare_value_struct_conversion!(struct sixtyfps_corelib::input::KeyEvent { event_type, text, modifiers });
 declare_value_struct_conversion!(struct sixtyfps_corelib::layout::LayoutInfo { min, max, min_percent, max_percent, preferred, stretch });
 declare_value_struct_conversion!(struct sixtyfps_corelib::graphics::Point { x, y, ..Default::default()});
+declare_value_struct_conversion!(struct sixtyfps_corelib::items::PointerEvent { kind, button });
 
 /// Implement From / TryInto for Value that convert an `enum` to/from `Value::EnumerationValue`
 ///
@@ -311,6 +312,10 @@ declare_value_enum_conversion!(sixtyfps_corelib::items::ImageRendering, ImageRen
 declare_value_enum_conversion!(sixtyfps_corelib::input::KeyEventType, KeyEventType);
 declare_value_enum_conversion!(sixtyfps_corelib::items::EventResult, EventResult);
 declare_value_enum_conversion!(sixtyfps_corelib::items::FillRule, FillRule);
+declare_value_enum_conversion!(sixtyfps_corelib::items::StandardButtonKind, StandardButtonKind);
+declare_value_enum_conversion!(sixtyfps_corelib::items::PointerEventKind, PointerEventKind);
+declare_value_enum_conversion!(sixtyfps_corelib::items::PointerEventButton, PointerEventButton);
+declare_value_enum_conversion!(sixtyfps_corelib::items::DialogButtonRole, DialogButtonRole);
 
 impl From<sixtyfps_corelib::animations::Instant> for Value {
     fn from(value: sixtyfps_corelib::animations::Instant) -> Self {
@@ -516,6 +521,8 @@ impl ComponentCompiler {
     ///
     /// Diagnostics from previous calls are cleared when calling this function.
     ///
+    /// If the path is `"-"`, the file will be read from stdin.
+    ///
     /// This function is `async` but in practice, this is only asynchronous if
     /// [`Self::set_file_loader`] was called and its future is actually asynchronous.
     /// If that is not used, then it is fine to use a very simple executor, such as the one
@@ -656,6 +663,49 @@ impl ComponentDefinition {
         })
     }
 
+    /// Returns the names of all exported global singletons
+    pub fn globals(&self) -> impl Iterator<Item = String> + '_ {
+        // We create here a 'static guard, because unfortunately the returned type would be restricted to the guard lifetime
+        // which is not required, but this is safe because there is only one instance of the unerased type
+        let guard = unsafe { generativity::Guard::new(generativity::Id::new()) };
+        self.inner.unerase(guard).global_names()
+    }
+
+    /// List of publicly declared properties in the exported global singleton specified by its name.
+    pub fn global_properties(
+        &self,
+        global_name: &str,
+    ) -> Option<impl Iterator<Item = (String, ValueType)> + '_> {
+        // We create here a 'static guard, because unfortunately the returned type would be restricted to the guard lifetime
+        // which is not required, but this is safe because there is only one instance of the unerased type
+        let guard = unsafe { generativity::Guard::new(generativity::Id::new()) };
+        self.inner.unerase(guard).global_properties(global_name).map(|iter| {
+            iter.filter_map(|(prop_name, prop_type)| {
+                if prop_type.is_property_type() {
+                    Some((prop_name, prop_type.into()))
+                } else {
+                    None
+                }
+            })
+        })
+    }
+
+    /// List of publicly declared callbacks in the exported global singleton specified by its name.
+    pub fn global_callbacks(&self, global_name: &str) -> Option<impl Iterator<Item = String> + '_> {
+        // We create here a 'static guard, because unfortunately the returned type would be restricted to the guard lifetime
+        // which is not required, but this is safe because there is only one instance of the unerased type
+        let guard = unsafe { generativity::Guard::new(generativity::Id::new()) };
+        self.inner.unerase(guard).global_properties(global_name).map(|iter| {
+            iter.filter_map(|(prop_name, prop_type)| {
+                if matches!(prop_type, LangType::Callback { .. }) {
+                    Some(prop_name)
+                } else {
+                    None
+                }
+            })
+        })
+    }
+
     /// The name of this Component as written in the .60 file
     pub fn name(&self) -> &str {
         // We create here a 'static guard, because unfortunately the returned type would be restricted to the guard lifetime
@@ -1142,6 +1192,7 @@ fn globals() {
             r#"
     export global My-Super_Global := {
         property <int> the-property : 21;
+        callback my-callback();
     }
     export { My-Super_Global as AliasedGlobal }
     export Dummy := Rectangle {
@@ -1149,8 +1200,39 @@ fn globals() {
             .into(),
             "".into(),
         ),
-    );
-    let instance = definition.unwrap().create();
+    )
+    .unwrap();
+
+    assert_eq!(definition.globals().collect::<Vec<_>>(), vec!["My-Super_Global", "AliasedGlobal"]);
+
+    assert!(definition.global_properties("not-there").is_none());
+    {
+        let expected_properties = vec![("the-property".to_string(), ValueType::Number)];
+        let expected_callbacks = vec!["my-callback".to_string()];
+
+        let assert_properties_and_callbacks = |global_name| {
+            assert_eq!(
+                definition
+                    .global_properties(global_name)
+                    .map(|props| props.collect::<Vec<_>>())
+                    .as_ref(),
+                Some(&expected_properties)
+            );
+            assert_eq!(
+                definition
+                    .global_callbacks(global_name)
+                    .map(|props| props.collect::<Vec<_>>())
+                    .as_ref(),
+                Some(&expected_callbacks)
+            );
+        };
+
+        assert_properties_and_callbacks("My-Super-Global");
+        assert_properties_and_callbacks("My_Super-Global");
+        assert_properties_and_callbacks("AliasedGlobal");
+    }
+
+    let instance = definition.create();
     assert_eq!(
         instance.set_global_property("My_Super-Global", "the_property", Value::Number(44.)),
         Ok(())
@@ -1218,6 +1300,54 @@ fn globals() {
     );
 }
 
+#[test]
+fn component_definition_struct_properties() {
+    let mut compiler = ComponentCompiler::default();
+    let comp_def = spin_on::spin_on(
+        compiler.build_from_source(
+            r#"
+    export struct Settings := {
+        string_value: string,
+    }
+    export Dummy := Rectangle {
+        property <Settings> test;
+    }"#
+            .into(),
+            "".into(),
+        ),
+    )
+    .unwrap();
+
+    let props = comp_def.properties().collect::<Vec<(_, _)>>();
+
+    assert_eq!(props.len(), 1);
+    assert_eq!(props[0].0, "test");
+    assert_eq!(props[0].1, ValueType::Struct);
+
+    let instance = comp_def.create();
+
+    let valid_struct: Struct =
+        [("string_value".to_string(), Value::String("hello".into()))].iter().cloned().collect();
+
+    assert_eq!(instance.set_property("test", Value::Struct(valid_struct.clone())), Ok(()));
+    assert_eq!(instance.get_property("test").unwrap().value_type(), ValueType::Struct);
+
+    assert_eq!(instance.set_property("test", Value::Number(42.)), Err(SetPropertyError::WrongType));
+
+    let mut invalid_struct = valid_struct.clone();
+    invalid_struct.set_field("other".into(), Value::Number(44.));
+    assert_eq!(
+        instance.set_property("test", Value::Struct(invalid_struct)),
+        Err(SetPropertyError::WrongType)
+    );
+    let mut invalid_struct = valid_struct.clone();
+    invalid_struct.set_field("string_value".into(), Value::Number(44.));
+    assert_eq!(
+        instance.set_property("test", Value::Struct(invalid_struct)),
+        Err(SetPropertyError::WrongType)
+    );
+}
+
 #[cfg(feature = "ffi")]
 #[allow(missing_docs)]
 #[path = "ffi.rs"]
