@@ -361,7 +361,7 @@ pub fn eval_expression(expression: &Expression, local_context: &mut EvalLocalCon
             }
             Expression::BuiltinFunctionReference(BuiltinFunction::ImageSize, _) => {
                 if arguments.len() != 1 {
-                    panic!("internal error: incorrect argument count to ColorDarker")
+                    panic!("internal error: incorrect argument count to ImageSize")
                 }
                 if let Value::Image(img) = eval_expression(&arguments[0], local_context) {
                     let size = img.size();
@@ -374,6 +374,23 @@ pub fn eval_expression(expression: &Expression, local_context: &mut EvalLocalCon
                     panic!("First argument not an image");
                 }
             }
+            Expression::BuiltinFunctionReference(BuiltinFunction::ArrayLength, _) => {
+                if arguments.len() != 1 {
+                    panic!("internal error: incorrect argument count to ArrayLength")
+                }
+                match eval_expression(&arguments[0], local_context) {
+                    Value::Array(array) => {
+                        Value::Number(array.len() as f64)
+                    }
+                    Value::Model(model) => {
+                        model.model_tracker().track_row_count_changes();
+                        Value::Number(model.row_count() as f64)
+                    }
+                    _ => {
+                        panic!("First argument not an array");
+                    }
+                }
+            }
             Expression::BuiltinFunctionReference(BuiltinFunction::Rgb, _) => {
                 let r: i32 = eval_expression(&arguments[0], local_context).try_into().unwrap();
                 let g: i32 = eval_expression(&arguments[1], local_context).try_into().unwrap();
